function yui = im_resize(xui,newsize)

% function yui = im_resize(xui,newsize)
% Resize xui to newsize(1:2).
%
% Nick Kingsbury, Cambridge University, 2006.

wh = waitbar(0,'Resizing image');

% Calculate new image size
sx = size(xui);
if length(sx)==2, sx(3) = 1; end % Allow for xui being 2D.
sy = [newsize(1:2) sx(3)];

% ri and ci are the vectors of the row and column indices of the
% locations in xui from which each interpolated point in yui is to come.
% Original locations in xui are [0.5:(sx-0.5)].
% New locations are [0.5:(sy-0.5)] * (sx/sy).
ri = [0.5:sy(1)-0.5]' * (sx(1)/sy(1));
ci = [0.5:sy(2)-0.5] * (sx(2)/sy(2));

% Correct for Matlab indexing from [1:sx] instead of [0.5:(sx-0.5)],
% and ensure that values in rj and cj lie within the range 1 to sx.
rj = max(min(ri+0.5,sx(1)),1);
cj = max(min(ci+0.5,sx(2)),1);

% Perform the resizing of each colour slice using interp2().
yui = uint8(zeros(sy));
for k = 1:sx(3),
    yui(:,:,k) = uint8(interp2(double(xui(:,:,k)),cj,rj,'linear') + 0.5);
%    yui(:,:,k) = uint8(interp2(double(xui(:,:,k)),cj,rj,'cubic') + 0.5);
    waitbar(k/3); % Increment waitbar after each colour is done.
end

close(wh) % Close wait bar

return
