% ph_crop.m
%
% Script called by 'Crop' menu item in photo editor.
%
% Nick Kingsbury, Cambridge University, 2006.

switch mode
    
    case 'Init'  
        % Set up control button in the main window to get zoom coordinates.
        figure(1);
        set(promptbox,'str',...
         'Zoom in to desired crop window in ''Before'' and click this button:');
        set(contrbutton,'str','Get zoom coordinates',...
            'call','mode=''Get zoom''; ph_crop');
        
        % Open new fig window near top of screen for entering params.
        figure(2);
        set(gcf,'position',[fig2pos  260  100]);
        set(gcf,'numbertitle','off','name','Crop Image');
        
        % Set default crop limits, [xmin xmax ymin ymax].
        if exist('croplim') ~= 1, croplim = round(axis(h1)); end
        
        label = {'Xmin:','Xmax:','Ymin:','Ymax:'};
        for k = 1:4
            edbox(k) = uicontrol(gcf,'style','edit',...
                'string',sprintf('%d',croplim(k)),'pos',[70 90-20*k 60 20],...
                'call','mode=''Set limits''; ph_crop');
            uicontrol(gcf,'style','text','str',label{k},...
                'pos',[10 90-20*k 60 20]);
        end
        cropnow = uicontrol(gcf,'str','Crop now','pos',[150 70 90 20],...
            'call','mode=''Crop now''; ph_crop');
        closebtn = uicontrol(gcf,'str','Close','pos',[180 10 60 20],...
            'call','mode=''Close''; ph_crop');
        
    case 'Set limits'
        % Get crop limits from edbox(1:4).
        for k=1:4, 
            croplim(k) = round(sscanf(get(edbox(k),'string'),'%f')); 
        end
        % Apply bounds and rewrite them into edbox(1:4).
        sx = size(xui);
        croplim([1 3]) = min(max(croplim([1 3]),1),sx([2 1])-1);
        croplim([2 4]) = max(min(croplim([2 4]),sx([2 1])),croplim([1 3])+1);
        for k=1:4, 
            set(edbox(k),'string',sprintf('%d',croplim(k))); 
        end
        
    case 'Get zoom'
        % Get crop limits from current axis limits of 'Before' image.
        croplim = round(axis(h1)); 
        figure(2);
        % Apply bounds and write them into edbox(1:4).
        sx = size(xui);
        croplim([1 3]) = min(max(croplim([1 3]),1),sx([2 1])-1);
        croplim([2 4]) = max(min(croplim([2 4]),sx([2 1])),croplim([1 3])+1);
        for k=1:4, 
            set(edbox(k),'string',sprintf('%d',croplim(k))); 
        end
        
    case 'Crop now'
        % Update limits in case edbox(1:4) have changed.
        for k=1:4, 
            croplim(k) = round(sscanf(get(edbox(k),'string'),'%f')); 
        end
        sx = size(xui);
        croplim([1 3]) = min(max(croplim([1 3]),1),sx([2 1])-1);
        croplim([2 4]) = max(min(croplim([2 4]),sx([2 1])),croplim([1 3])+1);
        for k=1:4, 
            set(edbox(k),'string',sprintf('%d',croplim(k))); 
        end
        % Crop 'Before' image and place result in 'After'.
        yui = xui(croplim(3):croplim(4),croplim(1):croplim(2),:);
        newbefore=0; 
        showimages;
        
    case 'Close'
        close(2); 
        newbefore=1; 
        showimages;
            
    end
