% phedit.m - Photo Editing main program,
% for the Part IB Paper 8 Image Processing Option - Photo Editing.
%
% This script file opens the main figure window, sets up the GUI menu
% 'Image edit' and gets an input image file.
% Script files are used for this main program and also for the next level
% of functionality (files 'ph_...') in order to share the main workspace
% across all top-level functions.
%
% Nick Kingsbury, Cambridge University, 2006.

% Set up the main figure window to use most of a 1024x768 screen.
close all; % Close any open figures.
warning off; % Suppress warning messages about Erasemode.
figure(1);
% set(gcf,'position',[80  30   940   670]); % Change for other screen sizes.
set(gcf,'position',[80  30   940   600]); % Change for other screen sizes.
set(gcf,'numbertitle','off','name','IB Paper 8 - Photo Editor'); % Title

% Set up a blank prompt box and a control button in the main window. 
% promptbox = uicontrol(gcf,'style','text','pos',[10 640 160 30]);
% contrbutton = uicontrol(gcf,'pos',[30 620 120 20]);
promptbox = uicontrol(gcf,'style','text','pos',[10 570 160 30]);
contrbutton = uicontrol(gcf,'pos',[30 550 120 20]);
fig2pos = [400 530];

% Set up 'Photo-edit' pull-down menu for fig 1.
uim = uimenu('label','Photo-edit'); 

% Add individual items to the menu.
uimenu(uim,'label','Open ''Before''','call','ph_openfile');
uimenu(uim,'label','Reopen ''Before''',...
    'call','xui = imread(infile); showimages');
uimenu(uim,'label','Save ''After''','call','ph_savefile');
uimenu(uim,'label','Copy ''Before'' to ''After''',...
    'call','yui=xui; newbefore=0; showimages');
uimenu(uim,'label','Copy ''After'' to ''Before''',...
    'call','xui=yui; newbefore=1; showimages');
% Put a separator line above the next item.
uimenu(uim,'label','Crop','call','mode=''Init''; ph_crop','separator','on');
uimenu(uim,'label','Resize','call','mode=''Init''; ph_resize');
uimenu(uim,'label','Rotate','call','mode=''Init''; ph_rotate');
uimenu(uim,'label','Morph','call','mode=''Init''; ph_morph');
uimenu(uim,'label','Colour shift','call','mode=''Init''; ph_colourshift');
uimenu(uim,'label','Lighting shift','call','mode=''Init''; ph_lightshift');
uimenu(uim,'label','Add noise','call','mode=''Init''; ph_addnoise');
uimenu(uim,'label','Filter','call','mode=''Init''; ph_filter');
uimenu(uim,'label','Enhance','call','mode=''Init''; ph_enhance');

% If xui does not exist, get an input image file; else show existing images.
if exist('xui')~=1, ph_openfile;
else newbefore=1; showimages;
end

