% ph_lightshift.m
% Routine called by 'Lighting shift' menu item in photo editor.
%
% Nick Kingsbury, Cambridge University, November 2005.


% Set up figure window for Rotate commands
figure;
set(gcf,'position',[400  624  450  100]);
set(gcf,'numbertitle','off','name','Lighting Shift');

% Initialise colour correction gains
if exist('light') ~= 1, light = [1 1 1]'; end

% Buttons for different lighting ranges.
label = strvcat('Shadows:','Mid tones:','Highlights:');
for k = 1:3,
    ypos = 70 - 20*k; xpos = 40*k - 30;
    slide(k) = uicontrol(gcf,'style','slider',...
        'sliderstep',[1 10]/100,'pos',[xpos+60 ypos 120 20]);
    uicontrol(gcf,'style','text','str',label(k,:),'pos',[xpos ypos 60 20]);
    edbox(k) = uicontrol(gcf,'style','edit','pos',[xpos+180 ypos 60 20]);
end
uicontrol(gcf,'style','text','str','Adjust Lighting Balance','pos',[70 70 120 16]);

% Other buttons: slider, edit box, and accept box.
resetbal = uicontrol(gcf,'str','Reset balance','pos',[340 70 100 20]);
showhist = uicontrol(gcf,'str','Update histograms','pos',[340 40 100 20]);
accpt = uicontrol(gcf,'str','Accept','pos',[380 10 60 20]);

% Define callback strings:
% Update sliders and edit boxes from light and replot yui data.

cb1 = ['[yui,light] = im_lighting(xui,light);'...
       'for k=1:3, set(slide(k),''value'',0.5*light(k));'...
         'set(edbox(k),''string'',sprintf(''%.2f'',light(k))); end;'...
       'update_y; figure(2);'];
eval(cb1);
 
% Define callback functions for each button to set theta and perform rotation.
set(slide(1),'call',['light(1)=2*get(slide(1),''value'');' cb1]);
set(slide(2),'call',['light(2)=2*get(slide(2),''value'');' cb1]);
set(slide(3),'call',['light(3)=2*get(slide(3),''value'');' cb1]);
set(edbox(1),'call',['light(1)=sscanf(get(edbox(1),''string''),''%f'');' cb1]);
set(edbox(2),'call',['light(2)=sscanf(get(edbox(2),''string''),''%f'');' cb1]);
set(edbox(3),'call',['light(3)=sscanf(get(edbox(3),''string''),''%f'');' cb1]);
set(resetbal,'call',['light=[1 1 1]'';' cb1]);
set(showhist,'call','showimages;');
set(accpt,'call','xui=yui; close(gcf); showimages;');



