% ph_resize.m
% Routine called by 'Resize' menu item in photo editor.
%
% Nick Kingsbury, Cambridge University, 2006.

switch mode
    
    case 'Init'  
        % Open new fig window for entering params
        figure(2);
        set(gcf,'position',[fig2pos  260  100]);
        set(gcf,'numbertitle','off','name','Resize Image');
        sx = size(xui);
        
        % Set default size to that of xui and default scale to 1.
        if exist('newsize') ~= 1, newsize = [sx(1:2) 1]; end
        
        label = {'Ysize:','Xsize:','Scale:'};
        for k = 1:3
            edbox(k) = uicontrol(gcf,'style','edit','pos',[70 20*k-10 60 20]);
            uicontrol(gcf,'style','text','str',label{k},'pos',[10 20*k-10 60 20]);
        end
        for k=1:2, 
            set(edbox(k),'string',sprintf('%d',newsize(k)),...
                'call','mode=''Set size''; ph_resize'); 
        end;
        set(edbox(3),'string',sprintf('%.2f',newsize(3)),...
            'call','mode=''Set scale''; ph_resize');

        curvals = sprintf('Current values:  Xsize = %d;  Ysize = %d',sx(2),sx(1));
        uicontrol(gcf,'style','text','str',curvals,'pos',[10 70 240 20]);
        
        resizenow = uicontrol(gcf,'str','Resize now','pos',[160 40 80 20],...
            'call','mode=''Resize now''; ph_resize');
        closebtn = uicontrol(gcf,'str','Close','pos',[180 10 60 20],...
            'call','mode=''Close''; ph_resize');
        
    case 'Set size'
        % Update size directly from Xsize or Ysize boxes.
        for k=1:2, 
            newsize(k)=round(sscanf(get(edbox(k),'string'),'%f'));
            set(edbox(k),'string',sprintf('%d',newsize(k))); 
        end;
        set(edbox(3),'string',' '); % Scale is meaningless in this case.
        
    case 'Set scale'
        % Update from Scale box.
        newsize(3) = sscanf(get(edbox(3),'string'),'%f');
        newsize(1:2) = round(newsize(3) * sx(1:2));
        for k=1:2, 
            set(edbox(k),'string',sprintf('%d',newsize(k))); 
        end;
        set(edbox(3),'string',sprintf('%.2f',newsize(3)));
     
    case 'Resize now'
        % Get size from Xsize and Ysize boxes.
        for k=1:2, 
            newsize(k)=round(sscanf(get(edbox(k),'string'),'%f'));
        end;
        yui = im_resize(xui,newsize(1:2)); 
        newbefore = 0; 
        showimages;
        
    case 'Close'
        close(2); 
        newbefore = 1; 
        showimages;
        
    end
