function y = rgb2yuv(x)
%
% function y = rgb2yuv(x)
% 
% Convert a 3-layer RGB image x into a 3-layer YUV image y.
% The rules are:
%   Y = 0.3*R + 0.6*G + 0.1*B
%   U = 0.5*(B - Y) = 0.45*B - 0.15*R - 0.3*G
%   V = 0.625*(R - Y) = 0.4375*R - 0.375*G - 0.0625*B
%
% Nick Kingsbury, Cambridge University, 2006.

% Set up conversion matrix.
C = [0.3 0.6 0.1; -0.15 -0.3 0.45; 0.4375 -0.375 -0.0625];

% Convert each image layer into a column vector and multiply the 3 vectors by C'.
sx = size(x);
y = reshape(x,sx(1)*sx(2),sx(3)) * C';
y = reshape(y,sx); % Convert y back to the shape of x.

return
